@@ -17,6 +17,7 @@
 
 from __future__ import (division, print_function)
 
+import sys
 from math import isnan
 import numpy as np
 from numpy import float32
@@ -144,6 +145,9 @@ def compute_chirptimes(mchirp, eta, chi, flow):
 def compute_tau0(mc, flow):
     return 5. * mc * MTSUN_SI / (256 * (PI * flow * mc * MTSUN_SI)**(8./3))
 
+def compute_tau0_40(mc):
+    return compute_tau0(mc, 40.)
+
 
 class AlignedSpinTemplate(object):
     """
@@ -195,6 +199,7 @@ class AlignedSpinTemplate(object):
         self._metric = None
         self.sigmasq = 0.
         self._mchirp = compute_mchirp(m1, m2)
+        self.tau0_40 = compute_tau0_40(self._mchirp)
         self.tau0 = compute_tau0(self._mchirp, bank.flow)
         self._dur = duration
         self._f_final = None
@@ -342,6 +347,7 @@ class AlignedSpinTemplate(object):
 
     def _compute_waveform(self, df, f_final):
 
+        phi0 = 0  # This is a reference phase, and not an intrinsic parameter
         approx = lalsim.GetApproximantFromString( self.approximant )
 
         if lalsim.SimInspiralImplementedFDApproximants(approx):
@@ -874,8 +880,8 @@ class SpinTaylorF2Template(InspiralPrecessingSpinTemplate):
         return row
 
 
-class SpinTaylorT2FourierTemplate(InspiralPrecessingSpinTemplate):
-    approximant = "SpinTaylorT2Fourier"
+class SpinTaylorT5FourierTemplate(InspiralPrecessingSpinTemplate):
+    approximant = "SpinTaylorT5Fourier"
 
 class SpinTaylorT4Template(InspiralPrecessingSpinTemplate):
     approximant = "SpinTaylorT4"
@@ -955,7 +961,7 @@ waveforms = {
     "SpinTaylorT4": SpinTaylorT4Template,
     "SpinTaylorT5": SpinTaylorT5Template,
     "SpinTaylorF2": SpinTaylorF2Template,
-    "SpinTaylorT2Fourier": SpinTaylorT2FourierTemplate,
+    "SpinTaylorT5Fourier": SpinTaylorT5FourierTemplate,
     "SEOBNRv3":SEOBNRv3Template,
     "EOBNRv2HM_ROM":EOBNRHigherOrderModeTemplate,
     "EOBNRv2HM_ROM_AmpMax":EOBNRHigherOrderModeAmpMaxTemplate,
