@@ -33,14 +33,14 @@
  */
 
 /** \name Error Codes */
-/*@{*/
+/** @{ */
 #define GENERATEPPNINSPIRALTESTC_ENORM  0	/**< Normal exit */
 #define GENERATEPPNINSPIRALTESTC_ESUB   1	/**< Subroutine failed */
 #define GENERATEPPNINSPIRALTESTC_EARG   2	/**< Error parsing arguments */
 #define GENERATEPPNINSPIRALTESTC_EVAL   3	/**< Input argument out of valid range */
 #define GENERATEPPNINSPIRALTESTC_EFILE  4	/**< Could not open file */
 #define GENERATEPPNINSPIRALTESTC_EPRINT 5	/**< Wrote past end of message string */
-/*@}*/
+/** @} */
 
 /** \cond DONT_DOXYGEN */
 #define GENERATEPPNINSPIRALTESTC_MSGENORM  "Normal exit"
@@ -77,7 +77,6 @@
 #include <lal/Random.h>
 #include <lal/PrintFTSeries.h>
 #include <lal/TimeFreqFFT.h>
-#include <lal/LALMoment.h>
 
 #include <lal/LALInspiral.h>
 
@@ -179,12 +178,6 @@ do {                                                                 \
 } while (0)
 
 
-
-/* A function to convert INT8 nanoseconds to LIGOTimeGPS. */
-void
-I8ToLIGOTimeGPS( LIGOTimeGPS *output, INT8 input );
-
-
 int
 main(int argc, char **argv)
 {
@@ -376,7 +369,7 @@ main(int argc, char **argv)
   params.lengthIn = 0;
 
   /* Variable parameters. */
-  I8ToLIGOTimeGPS( &(params.epoch), EPOCH );
+  XLALINT8NSToGPS( &(params.epoch), EPOCH );
   params.deltaT = dt;
   params.mTot = m1 + m2;
   params.eta = m1*m2/( params.mTot*params.mTot );
@@ -476,14 +469,14 @@ main(int argc, char **argv)
   {
     LALSCreateVector( &stat, &ht.data, waveform.h->data->length );
     LALCCreateVector( &stat, &Hf.data, waveform.h->data->length / 2 + 1 );
-    LALCreateForwardRealFFTPlan( &stat, &fwdRealPlan, waveform.h->data->length, 0 );
+    fwdRealPlan = XLALCreateForwardREAL4FFTPlan( waveform.h->data->length, 0 );
 
     ht.f0 = 0;
     ht.deltaT = dt;
     for( i = 0; i < waveform.h->data->length ; i++)
       ht.data->data[i] = hoft->data[i];
 
-    LALTimeFreqRealFFT( &stat, &Hf, &ht, fwdRealPlan );
+    XLALREAL4TimeFreqFFT( &Hf, &ht, fwdRealPlan );
 
     if( ( fourier = fopen(fftout, "w")) == NULL)
       fourier = fopen("fftout", "w");
@@ -492,7 +485,7 @@ main(int argc, char **argv)
       fprintf(fourier," %f %1.6e %1.6e\n", f, crealf(Hf.data->data[i]), cimagf(Hf.data->data[i]));
     fclose(fourier);
 
-		LALDestroyRealFFTPlan( &stat, &fwdRealPlan );
+		XLALDestroyREAL4FFTPlan( fwdRealPlan );
     LALCDestroyVector( &stat, &Hf.data );
     LALSDestroyVector( &stat, &ht.data );
   }
@@ -574,15 +567,4 @@ main(int argc, char **argv)
   INFO( GENERATEPPNINSPIRALTESTC_MSGENORM );
   return GENERATEPPNINSPIRALTESTC_ENORM;
 }
-
-
-/* A function to convert INT8 nanoseconds to LIGOTimeGPS. */
-void
-I8ToLIGOTimeGPS( LIGOTimeGPS *output, INT8 input )
-{
-  INT8 s = input / 1000000000LL;
-  output->gpsSeconds = (INT4)( s );
-  output->gpsNanoSeconds = (INT4)( input - 1000000000LL*s );
-  return;
-}
 /** \endcond */
