@@ -73,14 +73,14 @@
  */
 
 /** \name Error Codes */
-/*@{*/
+/** @{ */
 #define GENERATEPPNINSPIRALTESTC_ENORM  0	/**< Normal exit */
 #define GENERATEPPNINSPIRALTESTC_ESUB   1	/**< Subroutine failed */
 #define GENERATEPPNINSPIRALTESTC_EARG   2	/**< Error parsing arguments */
 #define GENERATEPPNINSPIRALTESTC_EVAL   3	/**< Input argument out of valid range */
 #define GENERATEPPNINSPIRALTESTC_EFILE  4	/**< Could not open file */
 #define GENERATEPPNINSPIRALTESTC_EPRINT 5	/**< Wrote past end of message string */
-/*@}*/
+/** @} */
 
 /** \cond DONT_DOXYGEN */
 #define GENERATEPPNINSPIRALTESTC_MSGENORM  "Normal exit"
@@ -92,6 +92,7 @@
 
 #include <math.h>
 #include <stdlib.h>
+#include <lal/Date.h>
 #include <lal/LALStdio.h>
 #include <lal/LALStdlib.h>
 #include <lal/LALConstants.h>
@@ -175,10 +176,6 @@ if ( ( (val) < (lower) ) || ( (val) > (upper) ) )                    \
 }                                                                    \
 while (0)
 
-/* A function to convert INT8 nanoseconds to LIGOTimeGPS. */
-void
-I8ToLIGOTimeGPS( LIGOTimeGPS *output, INT8 input );
-
 
 int
 main(int argc, char **argv)
@@ -345,7 +342,7 @@ main(int argc, char **argv)
   params.lengthIn = 0;
 
   /* Variable parameters. */
-  I8ToLIGOTimeGPS( &(params.epoch), EPOCH );
+  XLALINT8NSToGPS( &(params.epoch), EPOCH );
   params.deltaT = dt;
   params.mTot = m1 + m2;
   params.eta = m1*m2/( params.mTot*params.mTot );
@@ -475,15 +472,4 @@ main(int argc, char **argv)
   INFO( GENERATEPPNINSPIRALTESTC_MSGENORM );
   return GENERATEPPNINSPIRALTESTC_ENORM;
 }
-
-
-/* A function to convert INT8 nanoseconds to LIGOTimeGPS. */
-void
-I8ToLIGOTimeGPS( LIGOTimeGPS *output, INT8 input )
-{
-  INT8 s = input / 1000000000LL;
-  output->gpsSeconds = (INT4)( s );
-  output->gpsNanoSeconds = (INT4)( input - 1000000000LL*s );
-  return;
-}
 /** \endcond */
